@@ -18,12 +18,12 @@ RSpec.context 'ZPool: Should Create' do
   solaris_agents.each do |agent|
     it 'creates a zpool resource' do
       # ZPool: ensure create
-      apply_manifest_on(agent, "zpool{ tstpool: ensure=>present, disk=>'/ztstpool/dsk1' }") do
-        assert_match(%r{ensure: created}, @result.stdout, "err: #{agent}")
+      apply_manifest_on(agent, "zpool{ tstpool: ensure=>present, disk=>'/ztstpool/dsk1' }") do |result|
+        assert_match(%r{ensure: created}, result.stdout, "err: #{agent}")
       end
 
-      on(agent, 'zpool list') do
-        assert_match(%r{tstpool}, @result.stdout, "err: #{agent}")
+      on(agent, 'zpool list') do |result|
+        assert_match(%r{tstpool}, result.stdout, "err: #{agent}")
       end
     end
   end
