@@ -1,4 +1,5 @@
 require 'beaker-rspec'
+require 'beaker-puppet'
 require 'beaker/module_install_helper'
 require 'beaker/puppet_install_helper'
 require 'voxpupuli/acceptance/spec_helper_acceptance'
@@ -18,6 +19,7 @@ end
 RSpec.configure do |c|
   c.before :suite do
     unless ENV['BEAKER_provision'] == 'no'
+      hosts.each { |host| host[:type] = 'aio' }
       run_puppet_install_helper
       install_module_on(hosts)
       install_module_dependencies_on(hosts)
